@@ -15,7 +15,7 @@ import numpy as np
 import nibabel
 from nibabel import gifti
 from tempfile import NamedTemporaryFile
-from scipy.spatial.kdtree import KDTree
+from scipy.spatial import KDTree
 from scipy.linalg import lstsq
 from scipy.sparse import coo_matrix
 
@@ -279,7 +279,8 @@ def import_flat(fs_subject, patch, hemis=['lh', 'rh'], cx_subject=None,
     database.db.clear_cache(cx_subject)
     # Remove overlays.svg file (FLATMAPS HAVE CHANGED)
     overlays_file = database.db.get_paths(cx_subject)['overlays']
-    os.unlink(overlays_file)
+    if os.path.exists(overlays_file):
+        os.unlink(overlays_file)
     # Regenerate it? 
 
 
