@@ -1,11 +1,15 @@
 import cortex
-import tempfile
 import numpy as np
+import tempfile
+import pytest
 
 from cortex import db, dataset
+from cortex.testing_utils import has_installed
 
 subj, xfmname, nverts, volshape = "S1", "fullhead", 304380, (31,100,100)
 
+no_inkscape = not has_installed('inkscape')
+
 def test_braindata():
     vol = np.random.randn(*volshape)
     tf = tempfile.TemporaryFile(suffix='.png')
@@ -185,6 +189,7 @@ def test_volumedata_copy_with_custom_mask():
     assert np.allclose(v.data, vc.data)
 
 
+@pytest.mark.skipif(no_inkscape, reason='Inkscape required')
 def test_int64_in_dataviewrgb():
     data = np.arange(np.product(volshape)).reshape(volshape, order='C')
     view = cortex.VolumeRGB(data, data + 1, data + 2, subject=subj,
@@ -196,6 +201,7 @@ def test_int64_in_dataviewrgb():
     cortex.quickshow(view)
 
 
+@pytest.mark.skipif(no_inkscape, reason='Inkscape required')
 def test_vmin_none_in_dataview2d():
     data = np.arange(np.product(volshape)).reshape(volshape, order='C')
     view = cortex.Volume2D(data, data + 1, subject=subj, xfmname=xfmname)
@@ -204,3 +210,40 @@ def test_vmin_none_in_dataview2d():
     data = np.arange(nverts)
     view = cortex.Vertex2D(data, data + 1, subject=subj)
     cortex.quickshow(view)
+
+def test_dataset_operators():
+    vol = cortex.Volume.random(subj, xfmname)
+    array = np.random.randn(*volshape)
+
+    assert np.allclose(vol.data + array, (vol + array).data)
+    assert np.allclose(vol.data - array, (vol - array).data)
+    assert np.allclose(vol.data * array, (vol * array).data)
+    assert np.allclose(vol.data // array, (vol // array).data) # floordiv
+    assert np.allclose(vol.data / array, (vol / array).data) # truediv
+    # numpy doesn't like fractional powers of negative numbers
+    assert np.allclose(vol.data ** array, (vol ** array).data, equal_nan=True)
+    assert np.allclose(-vol.data, (-vol).data)
+    assert np.allclose(abs(vol.data), abs(vol).data)
+
+def test_blend_curvature():
+    view = cortex.Vertex.empty(subj)
+    alpha = np.linspace(0, 1, view.data.size).reshape(view.data.shape)
+
+    # test alpha with float
+    view_rgb = view.blend_curvature(alpha)
+    # test alpha with bool
+    view_rgb = view.blend_curvature(alpha > 0.3)
+    # test that it returns a VertexRGB
+    assert isinstance(view_rgb, cortex.VertexRGB)
+
+    # test on Vertex2D
+    view_2d = cortex.Vertex2D(view_rgb.red.data, view_rgb.green.data, subj)
+    view_rgb = view_2d.blend_curvature(alpha)
+
+    # test on VertexRGB
+    view_rgb_new = view_rgb.blend_curvature(alpha)
+    # test that it returns a different VertexRGB
+    assert not np.allclose(view_rgb.red.data, view_rgb_new.red.data)
+    # test that it returns a VertexRGB with same values when alpha is ones
+    view_rgb_new = view_rgb.blend_curvature(np.ones_like(alpha))
+    assert np.allclose(view_rgb.red.data, view_rgb_new.red.data)
